@@ -9,7 +9,7 @@ module DiasporaFederation
       #   MUST assign them a guid - a random string of at least 16 chars.
       #   @see Validation::Rule::Guid
       #   @return [String] guid
-      property :guid
+      property :guid, :string
 
       # @!attribute [r] author
       #   The diaspora* ID of the person
@@ -19,12 +19,12 @@ module DiasporaFederation
       #   alias for author
       #   @see Person#author
       #   @return [String] diaspora* ID
-      property :author, alias: :diaspora_id, xml_name: :diaspora_handle
+      property :author, :string, alias: :diaspora_id, xml_name: :diaspora_handle
 
       # @!attribute [r] url
       #   @see Discovery::WebFinger#seed_url
       #   @return [String] link to the pod
-      property :url
+      property :url, :string
 
       # @!attribute [r] profile
       #   All profile data of the person
@@ -34,7 +34,7 @@ module DiasporaFederation
       # @!attribute [r] exported_key
       #   @see Discovery::HCard#public_key
       #   @return [String] public key
-      property :exported_key
+      property :exported_key, :string
     end
   end
 end
