@@ -24,25 +24,25 @@ module DiasporaFederation
       #   This signature is mandatory only when federating from an upstream author to the subscribers.
       #   @see Relayable#parent_author_signature
       #   @return [String] parent author signature
-      property :parent_author_signature, default: nil
+      property :parent_author_signature, :string, default: nil
 
       # @!attribute [r] target_guid
       #   Guid of a relayable to be deleted
       #   @see Comment#guid
       #   @return [String] target guid
-      property :target_guid
+      property :target_guid, :string
 
       # @!attribute [r] target_type
       #   A string describing a type of the target
       #   @see Retraction#target_type
       #   @return [String] target type
-      property :target_type
+      property :target_type, :string
 
       # @!attribute [r] author
       #   The diaspora* ID of the person who deletes a relayable
       #   @see Person#author
       #   @return [String] diaspora* ID
-      property :author, xml_name: :sender_handle
+      property :author, :string, xml_name: :sender_handle
 
       # @!attribute [r] target_author_signature
       #   Contains a signature of the entity using the private key of the
@@ -51,54 +51,15 @@ module DiasporaFederation
       #   author is done.
       #   @see Relayable#author_signature
       #   @return [String] target author signature
-      property :target_author_signature, default: nil
+      property :target_author_signature, :string, default: nil
 
-      # @!attribute [r] target
-      #   Target entity
-      #   @return [RelatedEntity] target entity
-      entity :target, Entities::RelatedEntity
-
-      # Use only {Retraction} for receive
-      # @return [Retraction] instance as normal retraction
-      def to_retraction
-        Retraction.new(author: author, target_guid: target_guid, target_type: target_type, target: target)
+      def initialize(*)
+        raise "Sending RelayableRetraction is not supported anymore! Use Retraction instead!"
       end
 
-      # @return [String] string representation of this object
-      def to_s
-        "RelayableRetraction:#{target_type}:#{target_guid}"
-      end
-
-      private
-
-      # @param [Nokogiri::XML::Element] root_node xml nodes
       # @return [Retraction] instance
-      private_class_method def self.populate_entity(root_node)
-        entity_data = entity_data(root_node)
-        entity_data[:target] = Retraction.send(:fetch_target, entity_data[:target_type], entity_data[:target_guid])
-        new(entity_data).to_retraction
-      end
-
-      # It updates also the signatures with the keys of the author and the parent
-      # if the signatures are not there yet and if the keys are available.
-      #
-      # @return [Hash] xml elements with updated signatures
-      def xml_elements
-        privkey = DiasporaFederation.callbacks.trigger(:fetch_private_key, author)
-
-        super.tap do |xml_elements|
-          fill_required_signature(privkey, xml_elements) unless privkey.nil?
-        end
-      end
-
-      # @param [OpenSSL::PKey::RSA] privkey private key of sender
-      # @param [Hash] hash hash given for a signing
-      def fill_required_signature(privkey, hash)
-        if target.parent.author == author && parent_author_signature.nil?
-          hash[:parent_author_signature] = SignedRetraction.sign_with_key(privkey, self)
-        elsif target.author == author && target_author_signature.nil?
-          hash[:target_author_signature] = SignedRetraction.sign_with_key(privkey, self)
-        end
+      def self.from_hash(hash)
+        Retraction.from_hash(hash)
       end
     end
   end
