@@ -19,7 +19,7 @@ end
 require "diaspora_federation/validators/rules/birthday"
 require "diaspora_federation/validators/rules/boolean"
 require "diaspora_federation/validators/rules/diaspora_id"
-require "diaspora_federation/validators/rules/diaspora_id_count"
+require "diaspora_federation/validators/rules/diaspora_id_list"
 require "diaspora_federation/validators/rules/guid"
 require "diaspora_federation/validators/rules/not_nil"
 require "diaspora_federation/validators/rules/public_key"
@@ -37,6 +37,7 @@ end
 require "diaspora_federation/validators/related_entity_validator"
 
 # abstract types
+require "diaspora_federation/validators/optional_aware_validator"
 require "diaspora_federation/validators/relayable_validator"
 
 # types
@@ -45,6 +46,7 @@ require "diaspora_federation/validators/account_migration_validator"
 require "diaspora_federation/validators/comment_validator"
 require "diaspora_federation/validators/contact_validator"
 require "diaspora_federation/validators/conversation_validator"
+require "diaspora_federation/validators/embed_validator"
 require "diaspora_federation/validators/event_participation_validator"
 require "diaspora_federation/validators/event_validator"
 require "diaspora_federation/validators/h_card_validator"
