@@ -1,10 +1,10 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::Message}.
-    class MessageValidator < Validation::Validator
+    class MessageValidator < OptionalAwareValidator
       include Validation
 
-      rule :author, %i[not_empty diaspora_id]
+      rule :author, :diaspora_id
       rule :guid, :guid
       rule :conversation_guid, :guid
 
